Module commitment

Module commitment 

A commitment is like a sealed envelope. You put some information inside the envelope, and then seal (commit) it. You can’t change what you’ve said, but also, no-one knows what you’ve said until you’re ready to open (open) the envelope and reveal its contents. Also it’s a special envelope that can only be opened by a special opener that you keep safe in your drawer.

Structs

HomomorphicCommitment
There are also different types of commitments that vary in their security guarantees, but all of them are represented by binary data; so HomomorphicCommitment implements ByteArray.

Enums

ExtensionDegree
The extension degree for extended Pedersen commitments. Currently this is limited to adding 5 base points to the default Pedersen commitment, but in theory it could be arbitrarily long, although practically, very few if any test cases will need to add more than 2 base points.

Traits

ExtendedHomomorphicCommitmentFactory
A trait for creating extended commitments that are based on a public key
HomomorphicCommitmentFactory
A trait for creating commitments